@@ -1,8 +1,8 @@
 require 5.006;
 use strict;
 use warnings;
-package Email::Valid;
-$Email::Valid::VERSION = '1.201';
+package Email::Valid 1.203;
+
 # ABSTRACT: Check validity of Internet email addresses
 our (
   $RFC822PAT,
@@ -148,6 +148,11 @@ sub _net_dns_query {
 
   # Check for valid MX records for $host
   if (@mx_entries) {
+    # Check for RFC-7505 Null MX
+    my $nmx = scalar @mx_entries;
+    if ($nmx == 1 && length($mx_entries[0]->exchange) == 0) {
+      return $self->details('mx');
+    }
     foreach my $mx (@mx_entries) {
       my $mxhost = $mx->exchange;
       my $query  = $Resolver->search($mxhost);
@@ -158,8 +163,10 @@ sub _net_dns_query {
     }
   }
 
-  # Chceck for A record for $host
-  my @a_rrs = Net::DNS::rr($Resolver, $host, 'A');
+  # Check for A record for $host
+  my $ans   = $Resolver->query($host, 'A');
+  my @a_rrs = $ans ? $ans->answer : ();
+
   if (@a_rrs) {
     foreach my $a_rr (@a_rrs) {
       return 1 unless $a_rr->type ne 'A';
@@ -723,7 +730,7 @@ Email::Valid - Check validity of Internet email addresses
 
 =head1 VERSION
 
-version 1.201
+version 1.203
 
 =head1 SYNOPSIS
 
@@ -740,6 +747,16 @@ Please note that there is no way to determine whether an
 address is deliverable without attempting delivery
 (for details, see L<perlfaq 9|http://perldoc.perl.org/perlfaq9.html#How-do-I-check-a-valid-mail-address>).
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 PREREQUISITES
 
 This module requires perl 5.004 or later and the L<Mail::Address> module.
@@ -940,7 +957,7 @@ Maurice Aubrey <maurice@hevanet.com>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Alexandr Ciornii Karel Miko McA Michael Schout Mohammad S Anwar Neil Bowers Ricardo SIGNES Steve Bertrand Svetlana Troy Morehouse
+=for stopwords Alexandr Ciornii Dan Book Gene Hightower Karel Miko McA Michael Schout Mohammad S Anwar Neil Bowers Ricardo Signes Steve Bertrand Svetlana Troy Morehouse Yanick Champoux
 
 =over 4
 
@@ -950,6 +967,14 @@ Alexandr Ciornii <alexchorny@gmail.com>
 
 =item *
 
+Dan Book <grinnz@gmail.com>
+
+=item *
+
+Gene Hightower <gene@digilicious.com>
+
+=item *
+
 Karel Miko <karel.miko@gmail.com>
 
 =item *
@@ -970,7 +995,11 @@ Neil Bowers <neil@bowers.com>
 
 =item *
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo Signes <rjbs@cpan.org>
+
+=item *
+
+Ricardo Signes <rjbs@semiotic.systems>
 
 =item *
 
@@ -984,6 +1013,10 @@ Svetlana <svetlana.wiczer@gmail.com>
 
 Troy Morehouse <troymore@nbnet.nb.ca>
 
+=item *
+
+Yanick Champoux <yanick@babyl.dyndns.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
